# -*- coding: utf-8 -*-
"""
    pypbe
    Python Point Buy Equivalent
    ~~~~~~~~~~~~~~~
    Intended for tabletop rpgs such as Pathfinder or D&D, this module contains
    code to run a Monte Carlo simulation to determine the Point Buy Equivalent
    (PBE) for a given type of ability score rolling method, such as "Roll 4d6
    and drop the lowest".

    :copyright: (c) 2017 Eric Strong.
    :license: Refer to LICENSE.txt for more information.
"""

from .core import *


# -*- coding: utf-8 -*-
from distutils.core import setup
setup(
  name='pypbe',
  packages=['pypbe'],
  version='0.12',
  description='Module to calculate Point Buy Equivalent for Tabletop RPG',
  author='Eric Strong',
  author_email='dr.eric.strong@gmail.com',
  url='https://github.com/drericstrong/pypbe',
  download_url='https://github.com/drericstrong/pypbe/tarball/0.12',
  keywords=['RPG', 'Pathfinder', 'D&D', 'Tabletop', 'Point Buy', 'Point Buy Equivalent'],
  classifiers=[],
)
